@@ -25,43 +25,19 @@ class CreateProductSecretRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称，同一region内不可重复，最长128字节，使用字母、数字或者 - _ 的组合，第一个字符必须为字母或者数字。
-        :type SecretName: str
-        :param UserNamePrefix: 用户账号名前缀，由用户自行指定，长度限定在8个字符以内，
+        :param SecretName: 凭据名称，同一region内不可重复，最长128字节，使用字母、数字或者 - _ 的组合，第一个字符必须为字母或者数字。\n        :type SecretName: str\n        :param UserNamePrefix: 用户账号名前缀，由用户自行指定，长度限定在8个字符以内，
 可选字符集包括：
 数字字符：[0, 9]，
 小写字符：[a, z]，
 大写字符：[A, Z]，
 特殊字符(全英文符号)：下划线(_)，
-前缀必须以大写或小写字母开头。
-        :type UserNamePrefix: str
-        :param ProductName: 凭据所绑定的云产品名称，如Mysql，可以通过DescribeSupportedProducts接口获取所支持的云产品名称。
-        :type ProductName: str
-        :param InstanceID: 云产品实例ID。
-        :type InstanceID: str
-        :param Domains: 账号的域名，IP形式，支持填入%。
-        :type Domains: list of str
-        :param PrivilegesList: 将凭据与云产品实例绑定时，需要授予的权限列表。
-        :type PrivilegesList: list of ProductPrivilegeUnit
-        :param Description: 描述信息，用于详细描述用途等，最大支持2048字节。
-        :type Description: str
-        :param KmsKeyId: 指定对凭据进行加密的KMS CMK。
+前缀必须以大写或小写字母开头。\n        :type UserNamePrefix: str\n        :param ProductName: 凭据所绑定的云产品名称，如Mysql，可以通过DescribeSupportedProducts接口获取所支持的云产品名称。\n        :type ProductName: str\n        :param InstanceID: 云产品实例ID。\n        :type InstanceID: str\n        :param Domains: 账号的域名，IP形式，支持填入%。\n        :type Domains: list of str\n        :param PrivilegesList: 将凭据与云产品实例绑定时，需要授予的权限列表。\n        :type PrivilegesList: list of ProductPrivilegeUnit\n        :param Description: 描述信息，用于详细描述用途等，最大支持2048字节。\n        :type Description: str\n        :param KmsKeyId: 指定对凭据进行加密的KMS CMK。
 如果为空则表示使用Secrets Manager为您默认创建的CMK进行加密。
-您也可以指定在同region 下自行创建的KMS CMK进行加密。
-        :type KmsKeyId: str
-        :param Tags: 标签列表。
-        :type Tags: list of Tag
-        :param RotationBeginTime: 用户自定义的开始轮转时间，格式：2006-01-02 15:04:05。
-当EnableRotation为True时，此参数必填。
-        :type RotationBeginTime: str
-        :param EnableRotation: 是否开启轮转
+您也可以指定在同region 下自行创建的KMS CMK进行加密。\n        :type KmsKeyId: str\n        :param Tags: 标签列表。\n        :type Tags: list of Tag\n        :param RotationBeginTime: 用户自定义的开始轮转时间，格式：2006-01-02 15:04:05。
+当EnableRotation为True时，此参数必填。\n        :type RotationBeginTime: str\n        :param EnableRotation: 是否开启轮转
 True -- 开启
 False -- 不开启
-如果不指定，默认为False。
-        :type EnableRotation: bool
-        :param RotationFrequency: 轮转周期，以天为单位，默认为1天。
-        :type RotationFrequency: int
-        """
+如果不指定，默认为False。\n        :type EnableRotation: bool\n        :param RotationFrequency: 轮转周期，以天为单位，默认为1天。\n        :type RotationFrequency: int\n        """
         self.SecretName = None
         self.UserNamePrefix = None
         self.ProductName = None
@@ -115,20 +91,10 @@ class CreateProductSecretResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 创建的凭据名称。
-        :type SecretName: str
-        :param TagCode: 标签操作的返回码. 0: 成功；1: 内部错误；2: 业务处理错误。
+        :param SecretName: 创建的凭据名称。\n        :type SecretName: str\n        :param TagCode: 标签操作的返回码. 0: 成功；1: 内部错误；2: 业务处理错误。
 注意：此字段可能返回 null，表示取不到有效值。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type TagCode: int
-        :param TagMsg: 标签操作的返回信息。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type TagMsg: str
-        :param FlowID: 创建云产品凭据异步任务ID号。
-        :type FlowID: int
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+注意：此字段可能返回 null，表示取不到有效值。\n        :type TagCode: int\n        :param TagMsg: 标签操作的返回信息。
+注意：此字段可能返回 null，表示取不到有效值。\n        :type TagMsg: str\n        :param FlowID: 创建云产品凭据异步任务ID号。\n        :type FlowID: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.TagCode = None
         self.TagMsg = None
@@ -151,21 +117,7 @@ class CreateSecretRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称，同一region内不可重复，最长128字节，使用字母、数字或者 - _ 的组合，第一个字符必须为字母或者数字。
-        :type SecretName: str
-        :param VersionId: 凭据版本，查询凭据信息时需要根据SecretName 和 VersionId进行查询，最长64 字节，使用字母、数字或者 - _ . 的组合并且以字母或数字开头。
-        :type VersionId: str
-        :param Description: 描述信息，用于详细描述用途等，最大支持2048字节。
-        :type Description: str
-        :param KmsKeyId: 指定对凭据进行加密的KMS CMK。如果为空则表示使用Secrets Manager为您默认创建的CMK进行加密。您也可以指定在同region 下自行创建的KMS CMK进行加密。
-        :type KmsKeyId: str
-        :param SecretBinary: 二进制凭据信息base64编码后的明文。SecretBinary 和 SecretString 必须且只能设置一个，最大支持4096字节。
-        :type SecretBinary: str
-        :param SecretString: 文本类型凭据信息明文（不需要进行base64编码）。SecretBinary 和 SecretString 必须且只能设置一个，，最大支持4096字节。
-        :type SecretString: str
-        :param Tags: 标签列表
-        :type Tags: list of Tag
-        """
+        :param SecretName: 凭据名称，同一region内不可重复，最长128字节，使用字母、数字或者 - _ 的组合，第一个字符必须为字母或者数字。\n        :type SecretName: str\n        :param VersionId: 凭据版本，查询凭据信息时需要根据SecretName 和 VersionId进行查询，最长64 字节，使用字母、数字或者 - _ . 的组合并且以字母或数字开头。\n        :type VersionId: str\n        :param Description: 描述信息，用于详细描述用途等，最大支持2048字节。\n        :type Description: str\n        :param KmsKeyId: 指定对凭据进行加密的KMS CMK。如果为空则表示使用Secrets Manager为您默认创建的CMK进行加密。您也可以指定在同region 下自行创建的KMS CMK进行加密。\n        :type KmsKeyId: str\n        :param SecretBinary: 二进制凭据信息base64编码后的明文。SecretBinary 和 SecretString 必须且只能设置一个，最大支持4096字节。\n        :type SecretBinary: str\n        :param SecretString: 文本类型凭据信息明文（不需要进行base64编码）。SecretBinary 和 SecretString 必须且只能设置一个，，最大支持4096字节。\n        :type SecretString: str\n        :param Tags: 标签列表\n        :type Tags: list of Tag\n        """
         self.SecretName = None
         self.VersionId = None
         self.Description = None
@@ -204,19 +156,9 @@ class CreateSecretResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 新创建的凭据名称。
-        :type SecretName: str
-        :param VersionId: 新创建的凭据版本。
-        :type VersionId: str
-        :param TagCode: 标签操作的返回码. 0: 成功；1: 内部错误；2: 业务处理错误
-注意：此字段可能返回 null，表示取不到有效值。
-        :type TagCode: int
-        :param TagMsg: 标签操作的返回信息
-注意：此字段可能返回 null，表示取不到有效值。
-        :type TagMsg: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 新创建的凭据名称。\n        :type SecretName: str\n        :param VersionId: 新创建的凭据版本。\n        :type VersionId: str\n        :param TagCode: 标签操作的返回码. 0: 成功；1: 内部错误；2: 业务处理错误
+注意：此字段可能返回 null，表示取不到有效值。\n        :type TagCode: int\n        :param TagMsg: 标签操作的返回信息
+注意：此字段可能返回 null，表示取不到有效值。\n        :type TagMsg: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.VersionId = None
         self.TagCode = None
@@ -239,11 +181,7 @@ class DeleteSecretRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定需要删除的凭据名称。
-        :type SecretName: str
-        :param RecoveryWindowInDays: 指定计划删除日期，单位（天），0（默认）表示立即删除， 1-30 表示预留的天数，超出该日期之后彻底删除。
-        :type RecoveryWindowInDays: int
-        """
+        :param SecretName: 指定需要删除的凭据名称。\n        :type SecretName: str\n        :param RecoveryWindowInDays: 指定计划删除日期，单位（天），0（默认）表示立即删除， 1-30 表示预留的天数，超出该日期之后彻底删除。\n        :type RecoveryWindowInDays: int\n        """
         self.SecretName = None
         self.RecoveryWindowInDays = None
 
@@ -267,13 +205,7 @@ class DeleteSecretResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定删除的凭据名称。
-        :type SecretName: str
-        :param DeleteTime: 凭据删除的日期，unix时间戳。
-        :type DeleteTime: int
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 指定删除的凭据名称。\n        :type SecretName: str\n        :param DeleteTime: 凭据删除的日期，unix时间戳。\n        :type DeleteTime: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.DeleteTime = None
         self.RequestId = None
@@ -292,11 +224,7 @@ class DeleteSecretVersionRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定凭据名称。
-        :type SecretName: str
-        :param VersionId: 指定该名称下需要删除的凭据的版本号。
-        :type VersionId: str
-        """
+        :param SecretName: 指定凭据名称。\n        :type SecretName: str\n        :param VersionId: 指定该名称下需要删除的凭据的版本号。\n        :type VersionId: str\n        """
         self.SecretName = None
         self.VersionId = None
 
@@ -320,13 +248,7 @@ class DeleteSecretVersionResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称。
-        :type SecretName: str
-        :param VersionId: 凭据版本号。
-        :type VersionId: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param VersionId: 凭据版本号。\n        :type VersionId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.VersionId = None
         self.RequestId = None
@@ -345,9 +267,7 @@ class DescribeAsyncRequestInfoRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param FlowID: 异步任务ID号。
-        :type FlowID: int
-        """
+        :param FlowID: 异步任务ID号。\n        :type FlowID: int\n        """
         self.FlowID = None
 
 
@@ -369,13 +289,7 @@ class DescribeAsyncRequestInfoResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param TaskStatus: 0:处理中，1:处理成功，2:处理失败
-        :type TaskStatus: int
-        :param Description: 任务描述信息。
-        :type Description: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param TaskStatus: 0:处理中，1:处理成功，2:处理失败\n        :type TaskStatus: int\n        :param Description: 任务描述信息。\n        :type Description: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TaskStatus = None
         self.Description = None
         self.RequestId = None
@@ -394,9 +308,7 @@ class DescribeRotationDetailRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定需要获取凭据轮转详细信息的凭据名称。
-        :type SecretName: str
-        """
+        :param SecretName: 指定需要获取凭据轮转详细信息的凭据名称。\n        :type SecretName: str\n        """
         self.SecretName = None
 
 
@@ -418,20 +330,10 @@ class DescribeRotationDetailResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param EnableRotation: 否允许轮转，True表示开启轮转，False表示禁止轮转。
-        :type EnableRotation: bool
-        :param Frequency: 轮转的频率，以天为单位，默认为1天。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type Frequency: int
-        :param LatestRotateTime: 最近一次轮转的时间，显式可见的时间字符串，格式 2006-01-02 15:04:05。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type LatestRotateTime: str
-        :param NextRotateBeginTime: 下一次开始轮转的时间，显式可见的时间字符串，格式 2006-01-02 15:04:05。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type NextRotateBeginTime: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param EnableRotation: 否允许轮转，True表示开启轮转，False表示禁止轮转。\n        :type EnableRotation: bool\n        :param Frequency: 轮转的频率，以天为单位，默认为1天。
+注意：此字段可能返回 null，表示取不到有效值。\n        :type Frequency: int\n        :param LatestRotateTime: 最近一次轮转的时间，显式可见的时间字符串，格式 2006-01-02 15:04:05。
+注意：此字段可能返回 null，表示取不到有效值。\n        :type LatestRotateTime: str\n        :param NextRotateBeginTime: 下一次开始轮转的时间，显式可见的时间字符串，格式 2006-01-02 15:04:05。
+注意：此字段可能返回 null，表示取不到有效值。\n        :type NextRotateBeginTime: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.EnableRotation = None
         self.Frequency = None
         self.LatestRotateTime = None
@@ -454,9 +356,7 @@ class DescribeRotationHistoryRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定需要获取凭据轮转历史的凭据名称。
-        :type SecretName: str
-        """
+        :param SecretName: 指定需要获取凭据轮转历史的凭据名称。\n        :type SecretName: str\n        """
         self.SecretName = None
 
 
@@ -478,13 +378,7 @@ class DescribeRotationHistoryResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param VersionIDs: 版本号列表。
-        :type VersionIDs: list of str
-        :param TotalCount: 版本号个数，可以给用户展示的版本号个数上限为10个。
-        :type TotalCount: int
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param VersionIDs: 版本号列表。\n        :type VersionIDs: list of str\n        :param TotalCount: 版本号个数，可以给用户展示的版本号个数上限为10个。\n        :type TotalCount: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.VersionIDs = None
         self.TotalCount = None
         self.RequestId = None
@@ -503,9 +397,7 @@ class DescribeSecretRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定需要获取凭据详细信息的凭据名称。
-        :type SecretName: str
-        """
+        :param SecretName: 指定需要获取凭据详细信息的凭据名称。\n        :type SecretName: str\n        """
         self.SecretName = None
 
 
@@ -527,38 +419,12 @@ class DescribeSecretResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称。
-        :type SecretName: str
-        :param Description: 凭据描述信息。
-        :type Description: str
-        :param KmsKeyId: 用于加密的KMS CMK ID。
-        :type KmsKeyId: str
-        :param CreateUin: 创建者UIN。
-        :type CreateUin: int
-        :param Status: 凭据状态：Enabled、Disabled、PendingDelete, Creating, Failed。
-        :type Status: str
-        :param DeleteTime: 删除日期，uinx 时间戳，非计划删除状态的凭据为0。
-        :type DeleteTime: int
-        :param CreateTime: 创建日期。
-        :type CreateTime: int
-        :param SecretType: 0 --  用户自定义凭据类型；1 -- 云产品凭据类型。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type SecretType: int
-        :param ProductName: 云产品名称。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type ProductName: str
-        :param ResourceID: 云产品实例ID。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type ResourceID: str
-        :param RotationStatus: 是否开启轮转：True -- 开启轮转；False -- 禁止轮转。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type RotationStatus: bool
-        :param RotationFrequency: 轮转周期，默认以天为单位。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type RotationFrequency: int
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param Description: 凭据描述信息。\n        :type Description: str\n        :param KmsKeyId: 用于加密的KMS CMK ID。\n        :type KmsKeyId: str\n        :param CreateUin: 创建者UIN。\n        :type CreateUin: int\n        :param Status: 凭据状态：Enabled、Disabled、PendingDelete, Creating, Failed。\n        :type Status: str\n        :param DeleteTime: 删除日期，uinx 时间戳，非计划删除状态的凭据为0。\n        :type DeleteTime: int\n        :param CreateTime: 创建日期。\n        :type CreateTime: int\n        :param SecretType: 0 --  用户自定义凭据类型；1 -- 云产品凭据类型。
+注意：此字段可能返回 null，表示取不到有效值。\n        :type SecretType: int\n        :param ProductName: 云产品名称。
+注意：此字段可能返回 null，表示取不到有效值。\n        :type ProductName: str\n        :param ResourceID: 云产品实例ID。
+注意：此字段可能返回 null，表示取不到有效值。\n        :type ResourceID: str\n        :param RotationStatus: 是否开启轮转：True -- 开启轮转；False -- 禁止轮转。
+注意：此字段可能返回 null，表示取不到有效值。\n        :type RotationStatus: bool\n        :param RotationFrequency: 轮转周期，默认以天为单位。
+注意：此字段可能返回 null，表示取不到有效值。\n        :type RotationFrequency: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.Description = None
         self.KmsKeyId = None
@@ -603,13 +469,7 @@ class DescribeSupportedProductsResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Products: 支持的产品列表。
-        :type Products: list of str
-        :param TotalCount: 支持的产品个数
-        :type TotalCount: int
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param Products: 支持的产品列表。\n        :type Products: list of str\n        :param TotalCount: 支持的产品个数\n        :type TotalCount: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Products = None
         self.TotalCount = None
         self.RequestId = None
@@ -628,9 +488,7 @@ class DisableSecretRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定停用的凭据名称。
-        :type SecretName: str
-        """
+        :param SecretName: 指定停用的凭据名称。\n        :type SecretName: str\n        """
         self.SecretName = None
 
 
@@ -652,11 +510,7 @@ class DisableSecretResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 停用的凭据名称。
-        :type SecretName: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 停用的凭据名称。\n        :type SecretName: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.RequestId = None
 
@@ -673,9 +527,7 @@ class EnableSecretRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定启用凭据的名称。
-        :type SecretName: str
-        """
+        :param SecretName: 指定启用凭据的名称。\n        :type SecretName: str\n        """
         self.SecretName = None
 
 
@@ -697,11 +549,7 @@ class EnableSecretResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 启用的凭据名称。
-        :type SecretName: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 启用的凭据名称。\n        :type SecretName: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.RequestId = None
 
@@ -724,11 +572,7 @@ class GetRegionsResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Regions: region列表。
-        :type Regions: list of str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param Regions: region列表。\n        :type Regions: list of str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Regions = None
         self.RequestId = None
 
@@ -745,12 +589,8 @@ class GetSecretValueRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定凭据的名称。
-        :type SecretName: str
-        :param VersionId: 指定对应凭据的版本号。
-对于云产品凭据如Mysql凭据，通过指定凭据名称和历史版本号来获取历史轮转凭据的明文信息，如果要获取当前正在使用的凭据版本的明文，需要将版本号指定为：SSM_Current。
-        :type VersionId: str
-        """
+        :param SecretName: 指定凭据的名称。\n        :type SecretName: str\n        :param VersionId: 指定对应凭据的版本号。
+对于云产品凭据如Mysql凭据，通过指定凭据名称和历史版本号来获取历史轮转凭据的明文信息，如果要获取当前正在使用的凭据版本的明文，需要将版本号指定为：SSM_Current。\n        :type VersionId: str\n        """
         self.SecretName = None
         self.VersionId = None
 
@@ -774,19 +614,9 @@ class GetSecretValueResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据的名称。
-        :type SecretName: str
-        :param VersionId: 该凭据对应的版本号。
-        :type VersionId: str
-        :param SecretBinary: 在创建凭据(CreateSecret)时，如果指定的是二进制数据，则该字段为返回结果，并且使用base64进行编码，应用方需要进行base64解码后获取原始数据。
-SecretBinary和SecretString只有一个不为空。
-        :type SecretBinary: str
-        :param SecretString: 在创建凭据(CreateSecret)时，如果指定的是普通文本数据，则该字段为返回结果。
-SecretBinary和SecretString只有一个不为空。
-        :type SecretString: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 凭据的名称。\n        :type SecretName: str\n        :param VersionId: 该凭据对应的版本号。\n        :type VersionId: str\n        :param SecretBinary: 在创建凭据(CreateSecret)时，如果指定的是二进制数据，则该字段为返回结果，并且使用base64进行编码，应用方需要进行base64解码后获取原始数据。
+SecretBinary和SecretString只有一个不为空。\n        :type SecretBinary: str\n        :param SecretString: 在创建凭据(CreateSecret)时，如果指定的是普通文本数据，则该字段为返回结果。
+SecretBinary和SecretString只有一个不为空。\n        :type SecretString: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.VersionId = None
         self.SecretBinary = None
@@ -815,13 +645,7 @@ class GetServiceStatusResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param ServiceEnabled: true表示服务已开通，false 表示服务尚未开通。
-        :type ServiceEnabled: bool
-        :param InvalidType: 服务不可用类型： 0-未购买，1-正常， 2-欠费停服， 3-资源释放。
-        :type InvalidType: int
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param ServiceEnabled: true表示服务已开通，false 表示服务尚未开通。\n        :type ServiceEnabled: bool\n        :param InvalidType: 服务不可用类型： 0-未购买，1-正常， 2-欠费停服， 3-资源释放。\n        :type InvalidType: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.ServiceEnabled = None
         self.InvalidType = None
         self.RequestId = None
@@ -840,9 +664,7 @@ class ListSecretVersionIdsRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称。
-        :type SecretName: str
-        """
+        :param SecretName: 凭据名称。\n        :type SecretName: str\n        """
         self.SecretName = None
 
 
@@ -864,14 +686,8 @@ class ListSecretVersionIdsResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称。
-        :type SecretName: str
-        :param Versions: VersionId列表。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type Versions: list of VersionInfo
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param Versions: VersionId列表。
+注意：此字段可能返回 null，表示取不到有效值。\n        :type Versions: list of VersionInfo\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.Versions = None
         self.RequestId = None
@@ -895,30 +711,16 @@ class ListSecretsRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Offset: 查询列表的起始位置，以0开始，不设置默认为0。
-        :type Offset: int
-        :param Limit: 单次查询返回的最大数量，0或不设置则使用默认值 20。
-        :type Limit: int
-        :param OrderType: 根据创建时间的排序方式，0或者不设置则使用降序排序， 1 表示升序排序。
-        :type OrderType: int
-        :param State: 根据凭据状态进行过滤。
+        :param Offset: 查询列表的起始位置，以0开始，不设置默认为0。\n        :type Offset: int\n        :param Limit: 单次查询返回的最大数量，0或不设置则使用默认值 20。\n        :type Limit: int\n        :param OrderType: 根据创建时间的排序方式，0或者不设置则使用降序排序， 1 表示升序排序。\n        :type OrderType: int\n        :param State: 根据凭据状态进行过滤。
 默认为0表示查询全部。
 1 --  表示查询Enabled 凭据列表。
 2 --  表示查询Disabled 凭据列表。
 3 --  表示查询PendingDelete 凭据列表。
 4 --  表示PendingCreate。
 5 --  表示CreateFailed。
-其中状态PendingCreate和CreateFailed只有在SecretType为云产品凭据时生效
-        :type State: int
-        :param SearchSecretName: 根据凭据名称进行过滤，为空表示不过滤。
-        :type SearchSecretName: str
-        :param TagFilters: 标签过滤条件。
-        :type TagFilters: list of TagFilter
-        :param SecretType: 0  -- 表示用户自定义凭据，默认为0。
+其中状态PendingCreate和CreateFailed只有在SecretType为云产品凭据时生效\n        :type State: int\n        :param SearchSecretName: 根据凭据名称进行过滤，为空表示不过滤。\n        :type SearchSecretName: str\n        :param TagFilters: 标签过滤条件。\n        :type TagFilters: list of TagFilter\n        :param SecretType: 0  -- 表示用户自定义凭据，默认为0。
 1  -- 表示用户云产品凭据。
-这个参数只能在云产品凭据(1)和用户自定义凭据(0)中二选一。
-        :type SecretType: int
-        """
+这个参数只能在云产品凭据(1)和用户自定义凭据(0)中二选一。\n        :type SecretType: int\n        """
         self.Offset = None
         self.Limit = None
         self.OrderType = None
@@ -957,13 +759,7 @@ class ListSecretsResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param TotalCount: 根据State和SearchSecretName 筛选的凭据总数。
-        :type TotalCount: int
-        :param SecretMetadatas: 返回凭据信息列表。
-        :type SecretMetadatas: list of SecretMetadata
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param TotalCount: 根据State和SearchSecretName 筛选的凭据总数。\n        :type TotalCount: int\n        :param SecretMetadatas: 返回凭据信息列表。\n        :type SecretMetadatas: list of SecretMetadata\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.SecretMetadatas = None
         self.RequestId = None
@@ -997,9 +793,7 @@ ColumnPrivileges
 
 当权限为TablePrivileges时，必须通过参数Database和TableName指定数据库名以及数据库中的表名；
 
-当权限为ColumnPrivileges时，必须通过参数Database、TableName和CoulmnName指定数据库、数据库中的表名以及表中的列名。
-        :type PrivilegeName: str
-        :param Privileges: 权限列表。
+当权限为ColumnPrivileges时，必须通过参数Database、TableName和CoulmnName指定数据库、数据库中的表名以及表中的列名。\n        :type PrivilegeName: str\n        :param Privileges: 权限列表。
 对于Mysql产品来说，可选权限值为：
 
 1. GlobalPrivileges 中权限的可选值为："SELECT","INSERT","UPDATE","DELETE","CREATE", "PROCESS", "DROP","REFERENCES","INDEX","ALTER","SHOW DATABASES","CREATE TEMPORARY TABLES","LOCK TABLES","EXECUTE","CREATE VIEW","SHOW VIEW","CREATE ROUTINE","ALTER ROUTINE","EVENT","TRIGGER"。
@@ -1012,17 +806,9 @@ ColumnPrivileges
 注意，不传该参数表示清除该权限。
 
 4. ColumnPrivileges 权限的可选值为："SELECT","INSERT","UPDATE","REFERENCES"。
-注意，不传该参数表示清除该权限。
-        :type Privileges: list of str
-        :param Database: 仅当PrivilegeName为DatabasePrivileges时这个值才有效。
-        :type Database: str
-        :param TableName: 仅当PrivilegeName为TablePrivileges时这个值才有效，并且此时需要填充Database显式指明所在的数据库实例。
-        :type TableName: str
-        :param ColumnName: 仅当PrivilegeName为ColumnPrivileges时这个值才生效，并且此时必须填充：
+注意，不传该参数表示清除该权限。\n        :type Privileges: list of str\n        :param Database: 仅当PrivilegeName为DatabasePrivileges时这个值才有效。\n        :type Database: str\n        :param TableName: 仅当PrivilegeName为TablePrivileges时这个值才有效，并且此时需要填充Database显式指明所在的数据库实例。\n        :type TableName: str\n        :param ColumnName: 仅当PrivilegeName为ColumnPrivileges时这个值才生效，并且此时必须填充：
 Database - 显式指明所在的数据库实例。
-TableName - 显式指明所在表
-        :type ColumnName: str
-        """
+TableName - 显式指明所在表\n        :type ColumnName: str\n        """
         self.PrivilegeName = None
         self.Privileges = None
         self.Database = None
@@ -1052,16 +838,8 @@ class PutSecretValueRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定需要增加版本的凭据名称。
-        :type SecretName: str
-        :param VersionId: 指定新增加的版本号，最长64 字节，使用字母、数字或者 - _ . 的组合并且以字母或数字开头。
-        :type VersionId: str
-        :param SecretBinary: 二进制凭据信息，使用base64编码。
-SecretBinary 和 SecretString 必须且只能设置一个。
-        :type SecretBinary: str
-        :param SecretString: 文本类型凭据信息明文（不需要进行base64编码），SecretBinary 和 SecretString 必须且只能设置一个。
-        :type SecretString: str
-        """
+        :param SecretName: 指定需要增加版本的凭据名称。\n        :type SecretName: str\n        :param VersionId: 指定新增加的版本号，最长64 字节，使用字母、数字或者 - _ . 的组合并且以字母或数字开头。\n        :type VersionId: str\n        :param SecretBinary: 二进制凭据信息，使用base64编码。
+SecretBinary 和 SecretString 必须且只能设置一个。\n        :type SecretBinary: str\n        :param SecretString: 文本类型凭据信息明文（不需要进行base64编码），SecretBinary 和 SecretString 必须且只能设置一个。\n        :type SecretString: str\n        """
         self.SecretName = None
         self.VersionId = None
         self.SecretBinary = None
@@ -1089,13 +867,7 @@ class PutSecretValueResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称。
-        :type SecretName: str
-        :param VersionId: 新增加的版本号。
-        :type VersionId: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param VersionId: 新增加的版本号。\n        :type VersionId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.VersionId = None
         self.RequestId = None
@@ -1114,9 +886,7 @@ class RestoreSecretRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定需要恢复的凭据名称。
-        :type SecretName: str
-        """
+        :param SecretName: 指定需要恢复的凭据名称。\n        :type SecretName: str\n        """
         self.SecretName = None
 
 
@@ -1138,11 +908,7 @@ class RestoreSecretResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称。
-        :type SecretName: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.RequestId = None
 
@@ -1159,9 +925,7 @@ class RotateProductSecretRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 需要轮转的凭据名。
-        :type SecretName: str
-        """
+        :param SecretName: 需要轮转的凭据名。\n        :type SecretName: str\n        """
         self.SecretName = None
 
 
@@ -1183,11 +947,7 @@ class RotateProductSecretResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param FlowID: 轮转异步任务ID号。
-        :type FlowID: int
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param FlowID: 轮转异步任务ID号。\n        :type FlowID: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.FlowID = None
         self.RequestId = None
 
@@ -1204,35 +964,11 @@ class SecretMetadata(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称
-        :type SecretName: str
-        :param Description: 凭据的描述信息
-        :type Description: str
-        :param KmsKeyId: 用于加密凭据的KMS KeyId
-        :type KmsKeyId: str
-        :param CreateUin: 创建者UIN
-        :type CreateUin: int
-        :param Status: 凭据状态：Enabled、Disabled、PendingDelete、Creating、Failed
-        :type Status: str
-        :param DeleteTime: 凭据删除日期，对于status为PendingDelete 的有效，unix时间戳
-        :type DeleteTime: int
-        :param CreateTime: 凭据创建时间，unix时间戳
-        :type CreateTime: int
-        :param KmsKeyType: 用于加密凭据的KMS CMK类型，DEFAULT 表示SecretsManager 创建的默认密钥， CUSTOMER 表示用户指定的密钥
-        :type KmsKeyType: str
-        :param RotationStatus: 1:--开启轮转；0--禁止轮转
-注意：此字段可能返回 null，表示取不到有效值。
-        :type RotationStatus: int
-        :param NextRotationTime: 下一次轮转开始时间，uinx 时间戳
-注意：此字段可能返回 null，表示取不到有效值。
-        :type NextRotationTime: int
-        :param SecretType: 0 -- 用户自定义凭据；1 -- 云产品凭据
-注意：此字段可能返回 null，表示取不到有效值。
-        :type SecretType: int
-        :param ProductName: 云产品名称，仅在SecretType为1，即凭据类型为云产品凭据时生效
-注意：此字段可能返回 null，表示取不到有效值。
-        :type ProductName: str
-        """
+        :param SecretName: 凭据名称\n        :type SecretName: str\n        :param Description: 凭据的描述信息\n        :type Description: str\n        :param KmsKeyId: 用于加密凭据的KMS KeyId\n        :type KmsKeyId: str\n        :param CreateUin: 创建者UIN\n        :type CreateUin: int\n        :param Status: 凭据状态：Enabled、Disabled、PendingDelete、Creating、Failed\n        :type Status: str\n        :param DeleteTime: 凭据删除日期，对于status为PendingDelete 的有效，unix时间戳\n        :type DeleteTime: int\n        :param CreateTime: 凭据创建时间，unix时间戳\n        :type CreateTime: int\n        :param KmsKeyType: 用于加密凭据的KMS CMK类型，DEFAULT 表示SecretsManager 创建的默认密钥， CUSTOMER 表示用户指定的密钥\n        :type KmsKeyType: str\n        :param RotationStatus: 1:--开启轮转；0--禁止轮转
+注意：此字段可能返回 null，表示取不到有效值。\n        :type RotationStatus: int\n        :param NextRotationTime: 下一次轮转开始时间，uinx 时间戳
+注意：此字段可能返回 null，表示取不到有效值。\n        :type NextRotationTime: int\n        :param SecretType: 0 -- 用户自定义凭据；1 -- 云产品凭据
+注意：此字段可能返回 null，表示取不到有效值。\n        :type SecretType: int\n        :param ProductName: 云产品名称，仅在SecretType为1，即凭据类型为云产品凭据时生效
+注意：此字段可能返回 null，表示取不到有效值。\n        :type ProductName: str\n        """
         self.SecretName = None
         self.Description = None
         self.KmsKeyId = None
@@ -1276,11 +1012,7 @@ class Tag(AbstractModel):
 
     def __init__(self):
         """
-        :param TagKey: 标签键
-        :type TagKey: str
-        :param TagValue: 标签值
-        :type TagValue: str
-        """
+        :param TagKey: 标签键\n        :type TagKey: str\n        :param TagValue: 标签值\n        :type TagValue: str\n        """
         self.TagKey = None
         self.TagValue = None
 
@@ -1304,11 +1036,7 @@ class TagFilter(AbstractModel):
 
     def __init__(self):
         """
-        :param TagKey: 标签键
-        :type TagKey: str
-        :param TagValue: 标签值
-        :type TagValue: list of str
-        """
+        :param TagKey: 标签键\n        :type TagKey: str\n        :param TagValue: 标签值\n        :type TagValue: list of str\n        """
         self.TagKey = None
         self.TagValue = None
 
@@ -1332,11 +1060,7 @@ class UpdateDescriptionRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定需要更新描述信息的凭据名。
-        :type SecretName: str
-        :param Description: 新的描述信息，最大长度2048个字节。
-        :type Description: str
-        """
+        :param SecretName: 指定需要更新描述信息的凭据名。\n        :type SecretName: str\n        :param Description: 新的描述信息，最大长度2048个字节。\n        :type Description: str\n        """
         self.SecretName = None
         self.Description = None
 
@@ -1360,11 +1084,7 @@ class UpdateDescriptionResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称。
-        :type SecretName: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.RequestId = None
 
@@ -1381,18 +1101,10 @@ class UpdateRotationStatusRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 云产品凭据名称。
-        :type SecretName: str
-        :param EnableRotation: 是否开启轮转。
+        :param SecretName: 云产品凭据名称。\n        :type SecretName: str\n        :param EnableRotation: 是否开启轮转。
 True -- 开启轮转；
-False -- 禁止轮转。
-        :type EnableRotation: bool
-        :param Frequency: 轮转周期，以天为单位，最小为30天，最大为365天。
-        :type Frequency: int
-        :param RotationBeginTime: 用户设置的期望开始轮转时间，格式为：2006-01-02 15:04:05。
-当EnableRotation为True时，如果不填RotationBeginTime，则默认填充为当前时间。
-        :type RotationBeginTime: str
-        """
+False -- 禁止轮转。\n        :type EnableRotation: bool\n        :param Frequency: 轮转周期，以天为单位，最小为30天，最大为365天。\n        :type Frequency: int\n        :param RotationBeginTime: 用户设置的期望开始轮转时间，格式为：2006-01-02 15:04:05。
+当EnableRotation为True时，如果不填RotationBeginTime，则默认填充为当前时间。\n        :type RotationBeginTime: str\n        """
         self.SecretName = None
         self.EnableRotation = None
         self.Frequency = None
@@ -1420,9 +1132,7 @@ class UpdateRotationStatusResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -1437,16 +1147,8 @@ class UpdateSecretRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 指定需要更新凭据内容的名称。
-        :type SecretName: str
-        :param VersionId: 指定需要更新凭据内容的版本号。
-        :type VersionId: str
-        :param SecretBinary: 新的凭据内容为二进制的场景使用该字段，并使用base64进行编码。
-SecretBinary 和 SecretString 只能一个不为空。
-        :type SecretBinary: str
-        :param SecretString: 新的凭据内容为文本的场景使用该字段，不需要base64编码SecretBinary 和 SecretString 只能一个不为空。
-        :type SecretString: str
-        """
+        :param SecretName: 指定需要更新凭据内容的名称。\n        :type SecretName: str\n        :param VersionId: 指定需要更新凭据内容的版本号。\n        :type VersionId: str\n        :param SecretBinary: 新的凭据内容为二进制的场景使用该字段，并使用base64进行编码。
+SecretBinary 和 SecretString 只能一个不为空。\n        :type SecretBinary: str\n        :param SecretString: 新的凭据内容为文本的场景使用该字段，不需要base64编码SecretBinary 和 SecretString 只能一个不为空。\n        :type SecretString: str\n        """
         self.SecretName = None
         self.VersionId = None
         self.SecretBinary = None
@@ -1474,13 +1176,7 @@ class UpdateSecretResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称。
-        :type SecretName: str
-        :param VersionId: 凭据版本号。
-        :type VersionId: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SecretName: 凭据名称。\n        :type SecretName: str\n        :param VersionId: 凭据版本号。\n        :type VersionId: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SecretName = None
         self.VersionId = None
         self.RequestId = None
@@ -1499,11 +1195,7 @@ class VersionInfo(AbstractModel):
 
     def __init__(self):
         """
-        :param VersionId: 版本号。
-        :type VersionId: str
-        :param CreateTime: 创建时间，unix时间戳。
-        :type CreateTime: int
-        """
+        :param VersionId: 版本号。\n        :type VersionId: str\n        :param CreateTime: 创建时间，unix时间戳。\n        :type CreateTime: int\n        """
         self.VersionId = None
         self.CreateTime = None
 
